.. _geodesics:

Geodesics
=========

Graph-to-graph distances using curvature filtrations. Pick your curvature; get a distance matrix back.

Curvatures
----------

- ``forman_curvature`` (fast)
- ``balanced_forman_curvature``
- ``resistance_curvature``
- ``ollivier_ricci_curvature`` (most detailed, slowest)

API
---

.. automodule:: thema.multiverse.universe.geodesics
   :members:
   :undoc-members:
   :show-inheritance:
